﻿Set-Location $PSScriptRoot
$global:last_status="None"

function read_values {
    if (Test-Path -Path ./server.dns) {
        $global:server_dns=Get-Content -Path ./server.dns
    } else {
        $global:server_dns="Not specified (required for imaging via fileset and setting custom fields)"
    }

    if (Test-Path ./app.token) {
        $global:api_token="Present"
    } else {
        $global:api_token="Not present (required for imaging via fileset and setting custom fields)"
    }

    if (Test-Path ./debug.on) {
        $global:debug_mode="On"
    } else {
        $global:debug_mode="Off"
    }

    if (Test-Path ./mode.reimage) {
        $global:imaging_mode="Reimage (always try to restore image)"
    } else {
        $global:imaging_mode="Prompt (ask user whether they want to capture or restore image)"
    }

    if (Test-Path ../sysprep/unattend.xml) {
        $global:sysprep_file="Present"
    } else {
        $global:sysprep_file="Not present"
    }

    if (Test-Path ../fwclient/FileWaveClient.msi) {
        $global:fw_client=Get-Content -Path ../fwclient/fw_client_version.txt
    } else {
        $global:fw_client="Not present (Required for imaging. Please upload before restoring images.)"
    }
}

function show_menu {
    Write-Output "Last Status: $last_status"
    Write-Output ""
    Write-Output "Current Config"
    Write-Output "=============="
    Write-Output "Imaging mode: $imaging_mode"
    Write-Output "Debug: $debug_mode"
    Write-Output "Sysprep answer file: $sysprep_file"
    Write-Output "FW client version: $fw_client"
    Write-Output "FileWave server DNS: $server_dns"
    Write-Output "API base64 token: $api_token"
    Write-Output ""
    Write-Output "Available Commands"
    Write-Output "=================="
    Write-Output "1. Toggle imaging mode"
    Write-Output "2. Toggle debug mode"
    Write-Output "3. Set FW server DNS"
    Write-Output "4. Set API token"
    Write-Output "5. Quit"
    Write-Output ""
    $global:choice=Read-Host "What do you want to do "
}

do {
    read_values
    cls
    show_menu

    if ( $choice -match "1" ){
        if (Test-Path ./mode.reimage) {
            Remove-Item "./mode.reimage"
            $last_status="Imaging mode set to prompt"
        } else {
            Out-File "./mode.reimage"
            $last_status="Imaging mode set to reimage"
        }
    } elseif ($choice -match "2") {
        if (Test-Path ./debug.on) {
            Remove-Item "./debug.on"
            $last_status="Debug mode disabled"
        } else {
            Out-File "./debug.on"
            $last_status="Debug mode enabled"
        }
    } elseif ($choice -match "3") {
        $server_dns=Read-Host -Prompt "Enter FQDN for your FileWave server "
        $server_dns | Out-File ./server.dns
        $last_status="Server DNS updated to $server_dns"
    } elseif ($choice -match "4") {
        $api_token=Read-Host -Prompt "Enter API token for your FileWave server "
        $api_token | Out-File ./app.token
        $last_status="API token updated to $api_token"
    } elseif ($choice -match "5") {
        exit
    } else {
        $last_status="Invalid choice. Try again."
    }
}
while ($choice -notmatch "5")
