if (-NOT ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")) {
    Write-Output "Insufficient permissions to run this script. Open the PowerShell console as an administrator and run this script again."
    Read-Host -Prompt "Press Enter to quit"
    exit
}

clear
Set-Location $PSScriptRoot

if (Test-Path .\ReadMe.txt) {
} else {
    Write-Host "This script cannot be run locally but must be run from its location on the psimage network share"
    Read-Host -Prompt "Press Enter to quit"
    exit
}

$vendor=((wmic csproduct get vendor) -split '\n')[2] -replace '\s',''
$model=((wmic csproduct get name) -split '\n')[2] -replace '\s',''
$version=((wmic csproduct get version) -split '\n')[2] -replace '\s',''

#Account for Lenpovo putting model name in version field    
if ($vendor -match "LENOVO") {
    $model=$version
}

$model_path="$env:WINDIR\Temp\$model"

if (Test-Path .\$model) {
    Write-Host "Drivers have already been uploaded for this model"
    do {
        $answer=Read-Host -Prompt "Re-upload anyways (yes/no)"
    } until ($answer -match "yes" -or $answer -match "no")
    if ($answer -match "no") {
        exit
    }
}

Write-Output "Computer model is $model"
Write-Output "Exporting 3rd party drivers for $model"

mkdir $model_path

dism /online /export-driver /destination:"$model_path"

Write-Output ""
Write-Output "Uploading drivers to drivers folder"
Move-Item -Path $model_path -Destination .\ -Force

Write-Output "Driver upload done"