$global:logpath="C:\Windows\Temp\psimage.log"
$new_name=(gc C:\Windows\Temp\psimage\computername.txt).ToUpper()
$computername=$env:COMPUTERNAME

function timestamp {
    $time=get-date -format "MM/dd/yyyy HH:mm"
    return $time
}

Add-Content $logpath "Computername is $computername. Assigned name is $new_name."

if ($computername -match $new_name) {
    Add-Content $logpath "Computername matches assigned name. Checking if FileWave client installed."
    if ((Get-Process) -match "fwcld") {
        Add-Content $logpath "FileWave client already installed"

        do {
            Write-Output "Waiting 10 seconds for initial inventory to complete"
            Start-Sleep 10
        } until (Select-String -Path C:\ProgramData\FileWave\FWClient\fwcld.log -Pattern "Data successfully sent to the inventory server")
 
        $temp=timestamp
        Add-Content $logpath "$temp - Inventory successfully sent to FileWave server"
        Add-Content $logpath "FileWave client entry should appear in Admin with inventory"

        $temp=timestamp
        Add-Content $logpath "$temp - Begin cleanup pass"

        if (Test-Path "c:\windows\temp\psimage\to_do.bat") {
            Add-Content $logpath "to_do.bat found. Running script."
            start-process -filepath "c:\windows\temp\psimage\to_do.bat" -wait -passthru
        }

        $auto_user=(Get-ItemProperty -Path "HKLM:\Software\Microsoft\Windows NT\CurrentVersion\Winlogon").DefaultUserName
        Add-Content $logpath "Disabling autologin and removing $auto_user account" 

        Remove-ItemProperty -Path "HKLM:\Software\Microsoft\Windows NT\CurrentVersion\Winlogon" -Name "DefaultUserName"
        Remove-ItemProperty -Path "HKLM:\Software\Microsoft\Windows NT\CurrentVersion\Winlogon" -Name "DefaultPassword"
        Remove-ItemProperty -Path "HKLM:\Software\Microsoft\Windows NT\CurrentVersion\Winlogon" -Name "AutoAdminLogon"

        Disable-LocalUser -Name "$auto_user"
        Remove-LocalGroupMember -Group "Administrators" -Member "$auto_user"
        Remove-LocalUser -Name "$auto_user"

        Add-Content $logpath "Removing psimage folder" 
        Remove-Item 'C:\Windows\Temp\psimage' -Recurse

        $temp=timestamp
        New-ItemProperty -Path "HKLM:\Software\PSImage" -Name "ImageEnd" -Value "$temp"
        Add-Content $logpath "$temp - End cleanup pass"

        #To be used in fileset requirements scripts to ensure they don't run until the disk imaging is finished
        Add-Content "C:\Windows\Temp\restore.done" ""

        Restart-Computer
        exit      
    } else {
        $temp=timestamp
        Add-Content $logpath "$temp - Begin client installation pass"

        Add-Content $logpath "FileWave client not found. Installing client."
        start-process -filepath "C:\Windows\System32\msiexec.exe" -argumentlist '/i C:\Windows\Temp\psimage\FileWaveClient.msi /qb' -wait -passthru
 
        #Wait for Visual C++ redistributable to finish installing on slower PCs, usually those with spindle drives.
        do {
            Start-Sleep 5
        } until (Get-WmiObject -Class Win32_Product | Where-Object{$_.Name -match "Microsoft Visual C\+\+ 2019 X86"})

        while (!(Get-Process) -match "fwcld") { Start-Sleep 5 }
        Add-Content $logpath "FileWave client launched successfully"

        Add-Content $logpath "Adding Windows firewall exception for FileWave client"
        Start-Process -FilePath "c:\windows\temp\psimage\fw_exception.bat" -Wait -PassThru

        if (Test-Path "C:\Windows\Temp\psimage\custom") {
            Add-Content $logpath "Found Kiosk customization folder. Applying customizations."
            Copy-Item -Path "C:\Windows\Temp\psimage\custom" -Destination "C:\Program Files (x86)\FileWave" -Recurse
        }

        New-ItemProperty -Path "HKLM:\Software\Microsoft\Windows\CurrentVersion\RunOnce" -Name "!PSImage2" -Value "c:\WINDOWS\system32\WindowsPowerShell\v1.0\powershell.exe -ExecutionPolicy Bypass -File c:\windows\temp\psimage\runonce.ps1"

        $temp=timestamp
        Add-Content $logpath "$temp - End client installation pass"

        Restart-Computer
        exit
    }
    
} else {
    $temp=timestamp
    Add-Content $logpath "$temp - Begin renaming pass"

    #Import Wi-Fi profile if present so don't have to leave USB ethernet plugged in for post-imaging on laptops
    if (Get-Service | Where-Object Status -match "Running" | Where-Object DisplayName -match "WLAN AutoConfig") {
        Add-Content $logpath "Wireless adapter detected"
        if (Test-Path c:\windows\temp\psimage\wi-fi.xml) {
            Add-Content $logpath "Wi-Fi profile detected. Importing profile."
            netsh wlan add profile filename="c:\windows\temp\psimage\wi-fi.xml"
        } else {
            Add-Content $logpath "But no Wi-Fi profile was found"

        }
    }

    Add-Content $logpath "Computername doesn't match assigned name. Renaming computer and rebooting."
    Rename-Computer -NewName "$new_name"
    New-ItemProperty -Path "HKLM:\Software\Microsoft\Windows\CurrentVersion\RunOnce" -Name "!PSImage1" -Value "c:\WINDOWS\system32\WindowsPowerShell\v1.0\powershell.exe -ExecutionPolicy Bypass -File c:\windows\temp\psimage\runonce.ps1"

    $temp=timestamp
    Add-Content $logpath "$temp - End renaming pass"

    Restart-Computer
    exit
}
